==> gcloud-oauth-vue-0.1.18.tgz: package/src/router/default_router.js <==
/* Layout */
import Layout from '../layout'

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
 let defaultRouters = [
  {
    path: '/',
    redirect: '/private/dashboard',
  },
  {
    path: '/login',
    name: 'login',
    hidden: true,
    component: () => import('../../packages/gcloud-login/src/main.vue')
  },
  {
    path: '/forget',
    name: 'forget',
    hidden: true,
    component: () => import('../../packages/gcloud-forget/src/main.vue')
  },
  {
    path: '/404',
    name: '404',
    hidden: true,
    component: () => import('../views/404/index.vue'),
  },
  {
    path: '/dashboard',
    component: Layout,
    children: [
      {
        path: '/private/profile',
        name: 'profile',
        hidden: true,
        meta:{title :"个人中心" , affix:false },
        component: () => import('../../packages/gcloud-profile/src/main.vue')
      },
      {
        path: '/private/dashboard',
        component: () => import('../views/index.vue'),
        name: 'dashboard',
        meta:{title :"驾驶舱" , affix:true }
      },
      {
        path: '/test',
        component: () => import('../views/test/index.vue'),
        name: 'test',
        meta:{title :"测试页面", affix:false }
      },
      {
        path: '/list',
        name: 'list',
        hidden: true,
        component: () => import('../../packages/gcloud-list/src/main.vue'),
        meta:{title :"列表页面", affix:false }
      }
    ]
  }
]

export  { defaultRouters }

==> gcloud-oauth-vue-0.2.0.tgz: package/src/router/default_router.js <==
/* Layout */
import Layout from '../layout'

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
 let defaultRouters = [
  {
    path: '/',
    redirect: '/private/zyc/home',
  },
  {
    path: '/login',
    name: 'login',
    hidden: true,
    component: () => import('../../packages/gcloud-login/src/main.vue')
  },
  {
    path: '/forget',
    name: 'forget',
    hidden: true,
    component: () => import('../../packages/gcloud-forget/src/main.vue')
  },
  {
    path: '/404',
    name: '404',
    hidden: true,
    component: () => import('../views/404/index.vue'),
  },
  {
    path: '/dashboard',
    component: Layout,
    children: [
      {
        path: '/private/profile',
        name: 'profile',
        hidden: true,
        meta:{title :"个人中心" , affix:false },
        component: () => import('../../packages/gcloud-profile/src/main.vue')
      },
      {
        path: '/private/dashboard',
        component: () => import('../views/index.vue'),
        name: 'dashboard',
        meta:{title :"驾驶舱" , affix:true }
      },
      {
        path: '/test',
        component: () => import('../views/test/index.vue'),
        name: 'test',
        meta:{title :"测试页面", affix:false }
      },
      {
        path: '/list',
        name: 'list',
        hidden: true,
        component: () => import('../../packages/gcloud-list/src/main.vue'),
        meta:{title :"列表页面", affix:false }
      }
    ]
  }
]

export  { defaultRouters }
